==> jscope_sdk-1.3.0r03.zip: jscope_sdk-1.3.0/lib/dcomponent/dcomponent_slider-1.1.0-min.js <==

DComponent.Slider=Class.cast({Extends:DComponent.Panel,Virtual:{procDrag:function(src,ec,sx,sy,ex,ey){},setButtonPosition:function(p){this._p=p;}},_sc:null,_p:0,_l:null,_lp:null,newInstance:function(id,dc,sc,w,h,ip){this.superClass(id,dc);this.setSize(w,h);this.append(sc);sc.setDragEvent(DComponent.handler(this,this.procDrag));this._sc=sc;this._p=ip;},loadValue:function(){return this._p;},setEventListener:function(l,lp){if(l.interfaceof&&l.interfaceof(DComponent.StatusChangedListener)){this._l=l;this._lp=lp;}
else{throw new Error("Listener must implement \"DComponent.StatusChangedListener\" interface.");}}});DComponent.SliderSwitch=Class.cast({Extends:DComponent.Slider,Implements:DComponent.Application.LayoutListener,UNDER_SELECT:null,_sels:null,_max:0,_pos:0,_wp:0,_u:0,_us:false,newInstance:function(id,dc,sc,w,h,ip,us){this.superClass(id,dc,sc,w,h,ip);if(h!==null){this.style("lineHeight",h);}
this._sels=[];this._us=us;if(us){this.UNDER_SELECT=DComponent.handler(this,this._underSelect);}
DComponent.getApplication().addLayoutListener(this);},setTexts:function(ts,dc){var tl=ts.length;var wp=Math.round(100/tl);this._sc.setSize(wp,null,"%");this._sc.style("zIndex",1);var tstb="display:inline-block; position:absolute; text-align:center; z-index:0; -webkit-user-select:none; -moz-user-select:none; width:"+wp+"%;";for(var i=0;i<tl;i++){var tc=new DComponent.Label(this.getID()+"_"+i);tc.vacuumEvent();var lp=wp*i
var tst=tstb+" left: "+lp+"%;";tc.style("cssText",tst);tc.attachDesign(dc);tc.setText(ts[i]);this.append(tc);this._sels.push(tc);if(this._us){tc.setEvent(this.UNDER_SELECT,i,null,true);}
if(this._p==i){this._setupButton(tc);this._sc.setPosition(lp,null,"%");}
this._wp=wp;}},procDrag:function(src,ec,sx,sy,ex,ey){var uc=this._sels.length;var max=this._max;if(!max){this._calcSize();max=this._max;}
var pos=this._pos+ex-sx;if(pos<0){pos=0;}
else if(pos>max){pos=max;}
if(ec==="dragend"){var pp=this._p;if(pos===0){this._p=0;}
else if(pos<max){var u=this._u;this._p=Math.round(pos/u)
pos=this._p*u;}
else{this._p=uc-1;}
if(pp!=this._p){this._setupButton(this._sels[this._p]);}
this._pos=pos;}
this._sc.setPosition(pos,0);},setButtonPosition:function(p){DComponent.Slider.prototype.setButtonPosition.call(this,p);this._sc.setPosition(this._wp*p,0,"%");},_setupButton:function(c){this._sc.removeChildren();var bc=c.clone(true,c.getID()+"_button");bc.setSize(100,null,"%");bc.setPosition(0,0);bc.attachDesign("selected");this._sc.append(bc);if(this._l){this._l.statusChanged(this,this._lp);}},_underSelect:function(src,i){if(i!=this._p){this._p=i;this._pos=this._u*i;this._setupButton(src);this.setButtonPosition(i);}},_calcSize:function(){var max=this._max=this.getBounds().width-this._sc.getBounds().width;var uc=this._sels.length;if(uc>1){this._u=Math.round(max/(uc-1));}
this._pos=this._u*this._p;},resetLayout:function(o){this._calcSize();this._sc.setPosition(this._pos,0);}});DComponent.SpinSwitch=Class.cast({Extends:DComponent.Slider,_sels:null,_sa:null,_max:0,_u:0,newInstance:function(id,dc,w,h,ip){this.superClass(id,dc,w,h,ip);this.style("overflow","hidden");this._sels=[];var sst="position:relative; widh:100%;";var sa=new DComponent.Panel(id+"_scroll_area",null,DComponent.Panel.LAYOUT_VERTICAL);sa.style("cssText",sst);this.append(sa);this._sa=sa;},setTexts:function(ts,dc){var tl=ts.length;this._sc.setSize(wp,null,"%");this._sc.style("zIndex",1);var tstb="display:inline-block; position:absolute; text-align:center; z-index:0; -webkit-user-select:none; -moz-user-select:none; width:100%; height:32%;";for(var i=0;i<tl;i++){var tc=new DComponent.Label(this.getID()+"_"+i);var lp=wp*i
var tst=tstb+" left: "+lp+"%;";tc.style("cssText",tst);tc.attachDesign(dc);tc.setText(ts[i]);this._sels.push(tc);}
this._setupButton();},procDrag:function(src,ec,sx,sy,ex,ey){var uc=this._sels.length;var max=this._max;if(!max){this._calcSize();max=this._max;}
var pos=this._pos+ex-sx;if(pos<0){pos=0;}
else if(pos>max){pos=max;}
if(ec==="dragend"){var pp=this._p;if(pos===0){this._p=0;}
else if(pos<max){var u=this._u;this._p=Math.round(pos/u)
pos=this._p*u;}
else{this._p=uc-1;}
if(pp!=this._p){this._setupButton(this._sels[this._p]);}
this._pos=pos;}
this._sc.setPosition(pos,0);},setButtonPosition:function(p){DComponent.Slider.prototype.setButtonPosition.call(this,p);this._sc.setPosition(this._wp*p,0,"%");},_setupButton:function(){var sz=this._sels.length;this._sa.removeChildren();for(var i=-2;i<4;i++){var p=this._p+i;if(i<0){p+=sz;}
if(i>=sz){p-=sz;}
this._sa.append(this._sels[p]);}
this._sa.setPosition(null,"-64%");},_calcSize:function(){this._max=Math.floor(this.getBounds().height*0.64);this._u=Math.round(max/(uc-1));},resetLayout:function(o){this._calcSize();this._setupButton();}});

==> jscope_sdk-1.5.0r09.zip: jscope_sdk-1.5.0/lib/dcomponent/dcomponent_slider-1.1.0-min.js <==

DComponent.Slider=Class.cast({Extends:DComponent.Panel,Virtual:{procDrag:function(src,ec,sx,sy,ex,ey){},setButtonPosition:function(p){this._p=p;}},_sc:null,_p:0,_l:null,_lp:null,newInstance:function(id,dc,sc,w,h,ip){this.superClass(id,dc);this.setSize(w,h);this.append(sc);sc.setDragEvent(DComponent.handler(this,this.procDrag));this._sc=sc;this._p=ip;},loadValue:function(){return this._p;},setEventListener:function(l,lp){if(Class.interfaceOf(l,DComponent.StatusChangedListener)){this._l=l;this._lp=lp;}
else{throw new Error("Listener must implement \"DComponent.StatusChangedListener\" interface.");}}});DComponent.SliderSwitch=Class.cast({Extends:DComponent.Slider,Implements:DComponent.Application.LayoutListener,UNDER_SELECT:null,_sels:null,_max:0,_pos:0,_wp:0,_u:0,_us:false,newInstance:function(id,dc,sc,w,h,ip,us){this.superClass(id,dc,sc,w,h,ip);if(h!==null){this.style("lineHeight",h);}
this._sels=[];this._us=us;if(us){this.UNDER_SELECT=DComponent.handler(this,this._underSelect);}
DComponent.getApplication().addLayoutListener(this);},setTexts:function(ts,dc){var tl=ts.length;var wp=Math.round(100/tl);this._sc.setSize(wp,null,"%");this._sc.style("zIndex",1);var tstb="display:inline-block; position:absolute; text-align:center; z-index:0; -webkit-user-select:none; -moz-user-select:none; width:"+wp+"%;";for(var i=0;i<tl;i++){var tc=new DComponent.Label(this.getID()+"_"+i);tc.vacuumEvent();var lp=wp*i
var tst=tstb+" left: "+lp+"%;";tc.style("cssText",tst);tc.attachDesign(dc);tc.setText(ts[i]);this.append(tc);this._sels.push(tc);if(this._us){tc.setEvent(this.UNDER_SELECT,i,null,true);}
if(this._p==i){this._setupButton(tc);this._sc.setPosition(lp,null,"%");}
this._wp=wp;}},procDrag:function(src,ec,sx,sy,ex,ey){var uc=this._sels.length;var max=this._max;if(!max){this._calcSize();max=this._max;}
var pos=this._pos+ex-sx;if(pos<0){pos=0;}
else if(pos>max){pos=max;}
if(ec==="dragend"){var pp=this._p;if(pos===0){this._p=0;}
else if(pos<max){var u=this._u;this._p=Math.round(pos/u)
pos=this._p*u;}
else{this._p=uc-1;}
if(pp!=this._p){this._setupButton(this._sels[this._p]);}
this._pos=pos;}
this._sc.setPosition(pos,0);},setButtonPosition:function(p){DComponent.Slider.prototype.setButtonPosition.call(this,p);this._sc.setPosition(this._wp*p,0,"%");},_setupButton:function(c){this._sc.removeChildren();var bc=c.clone(true,c.getID()+"_button");bc.setSize(100,null,"%");bc.setPosition(0,0);bc.attachDesign("selected");this._sc.append(bc);if(this._l){this._l.statusChanged(this,this._lp);}},_underSelect:function(src,i){if(i!=this._p){this._p=i;this._pos=this._u*i;this._setupButton(src);this.setButtonPosition(i);}},_calcSize:function(){var max=this._max=this.getBounds().width-this._sc.getBounds().width;var uc=this._sels.length;if(uc>1){this._u=Math.round(max/(uc-1));}
this._pos=this._u*this._p;},resetLayout:function(o){this._calcSize();this._sc.setPosition(this._pos,0);}});DComponent.SpinSwitch=Class.cast({Extends:DComponent.Slider,_sels:null,_sa:null,_max:0,_u:0,newInstance:function(id,dc,w,h,ip){this.superClass(id,dc,w,h,ip);this.style("overflow","hidden");this._sels=[];var sst="position:relative; widh:100%;";var sa=new DComponent.Panel(id+"_scroll_area",null,DComponent.Panel.LAYOUT_VERTICAL);sa.style("cssText",sst);this.append(sa);this._sa=sa;},setTexts:function(ts,dc){var tl=ts.length;this._sc.setSize(wp,null,"%");this._sc.style("zIndex",1);var tstb="display:inline-block; position:absolute; text-align:center; z-index:0; -webkit-user-select:none; -moz-user-select:none; width:100%; height:32%;";for(var i=0;i<tl;i++){var tc=new DComponent.Label(this.getID()+"_"+i);var lp=wp*i
var tst=tstb+" left: "+lp+"%;";tc.style("cssText",tst);tc.attachDesign(dc);tc.setText(ts[i]);this._sels.push(tc);}
this._setupButton();},procDrag:function(src,ec,sx,sy,ex,ey){var uc=this._sels.length;var max=this._max;if(!max){this._calcSize();max=this._max;}
var pos=this._pos+ex-sx;if(pos<0){pos=0;}
else if(pos>max){pos=max;}
if(ec==="dragend"){var pp=this._p;if(pos===0){this._p=0;}
else if(pos<max){var u=this._u;this._p=Math.round(pos/u)
pos=this._p*u;}
else{this._p=uc-1;}
if(pp!=this._p){this._setupButton(this._sels[this._p]);}
this._pos=pos;}
this._sc.setPosition(pos,0);},setButtonPosition:function(p){DComponent.Slider.prototype.setButtonPosition.call(this,p);this._sc.setPosition(this._wp*p,0,"%");},_setupButton:function(){var sz=this._sels.length;this._sa.removeChildren();for(var i=-2;i<4;i++){var p=this._p+i;if(i<0){p+=sz;}
if(i>=sz){p-=sz;}
this._sa.append(this._sels[p]);}
this._sa.setPosition(null,"-64%");},_calcSize:function(){this._max=Math.floor(this.getBounds().height*0.64);this._u=Math.round(max/(uc-1));},resetLayout:function(o){this._calcSize();this._setupButton();}});
